@@ -172,7 +172,8 @@ def get_config_parameter(config: ConfigParser,
                          section: str,
                          param: str,
                          fn: Callable[[Any], Any],
-                         default: Any) -> Any:
+                         default: Any = None,
+                         loglevel: int = logging.DEBUG) -> Any:
     """
     Fetch parameter from ``configparser`` ``.INI`` file.
 
@@ -182,6 +183,7 @@ def get_config_parameter(config: ConfigParser,
         param: name of parameter within section
         fn: function to apply to string parameter (e.g. ``int``)
         default: default value
+        loglevel: log level if default is needed
 
     Returns:
         parameter value, or ``None`` if ``default is None``, or ``fn(default)``
@@ -189,9 +191,10 @@ def get_config_parameter(config: ConfigParser,
     try:
         value = fn(config.get(section, param))
     except (TypeError, ValueError, NoOptionError):
-        log.warning(
-            "Configuration variable {} not found or improper in section [{}]; "
-            "using default of {!r}", param, section, default)
+        log.log(
+            level=loglevel,
+            msg=f"Configuration variable {param} not found or improper in "
+                f"section [{section}]; using default of {default!r}")
         if default is None:
             value = default
         else:
@@ -202,7 +205,8 @@ def get_config_parameter(config: ConfigParser,
 def get_config_parameter_boolean(config: ConfigParser,
                                  section: str,
                                  param: str,
-                                 default: bool) -> bool:
+                                 default: bool,
+                                 loglevel: int = logging.DEBUG) -> bool:
     """
     Get Boolean parameter from ``configparser`` ``.INI`` file.
 
@@ -211,15 +215,17 @@ def get_config_parameter_boolean(config: ConfigParser,
         section: section name within config file
         param: name of parameter within section
         default: default value
+        loglevel: log level if default is needed
     Returns:
         parameter value, or default
     """
     try:
         value = config.getboolean(section, param)
     except (TypeError, ValueError, NoOptionError):
-        log.warning(
-            "Configuration variable {} not found or improper in section [{}]; "
-            "using default of {!r}", param, section, default)
+        log.log(
+            level=loglevel,
+            msg=f"Configuration variable {param} not found or improper in "
+                f"section [{section}]; using default of {default!r}")
         value = default
     return value
 
@@ -227,7 +233,8 @@ def get_config_parameter_boolean(config: ConfigParser,
 def get_config_parameter_loglevel(config: ConfigParser,
                                   section: str,
                                   param: str,
-                                  default: int) -> int:
+                                  default: int,
+                                  loglevel: int = logging.DEBUG) -> int:
     """
     Get ``loglevel`` parameter from ``configparser`` ``.INI`` file, e.g.
     mapping ``'debug'`` to ``logging.DEBUG``.
@@ -237,6 +244,7 @@ def get_config_parameter_loglevel(config: ConfigParser,
         section: section name within config file
         param: name of parameter within section
         default: default value
+        loglevel: log level if default is needed
     Returns:
         parameter value, or default
     """
@@ -255,16 +263,18 @@ def get_config_parameter_loglevel(config: ConfigParser,
         else:
             raise ValueError
     except (TypeError, ValueError, NoOptionError, AttributeError):
-        log.warning(
-            "Configuration variable {} not found or improper in section [{}]; "
-            "using default of {!r}", param, section, default)
+        log.log(
+            level=loglevel,
+            msg=f"Configuration variable {param} not found or improper in "
+                f"section [{section}]; using default of {default!r}")
         return default
 
 
 def get_config_parameter_multiline(config: ConfigParser,
                                    section: str,
                                    param: str,
-                                   default: List[str]) -> List[str]:
+                                   default: List[str],
+                                   loglevel: int = logging.DEBUG) -> List[str]:
     """
     Get multi-line string parameter from ``configparser`` ``.INI`` file,
     as a list of strings (one per line, ignoring blank lines).
@@ -274,6 +284,7 @@ def get_config_parameter_multiline(config: ConfigParser,
         section: section name within config file
         param: name of parameter within section
         default: default value
+        loglevel: log level if default is needed
     Returns:
         parameter value, or default
     """
@@ -282,7 +293,8 @@ def get_config_parameter_multiline(config: ConfigParser,
         lines = [x.strip() for x in multiline.splitlines()]
         return [line for line in lines if line]
     except (TypeError, ValueError, NoOptionError):
-        log.warning(
-            "Configuration variable {} not found or improper in section [{}]; "
-            "using default of {!r}", param, section, default)
+        log.log(
+            level=loglevel,
+            msg=f"Configuration variable {param} not found or improper in "
+                f"section [{section}]; using default of {default!r}")
         return default
